<?php
declare(strict_types=1);

namespace Tiara\Mail\Transport;

use Laminas\Mail\Message;
use Laminas\Mail\Transport\TransportInterface;
use SendGrid;
use SendGrid\Mail\Mail;

/**
 * Class SendgridApi
 *
 * @package Tiara\Mail\Transport
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-mail
 */
final class SendgridApi implements TransportInterface
{
    private SendGrid $sendgrid;

    /**
     * Konstruktor.
     *
     * @param SendGrid $sendgrid
     */
    public function __construct(SendGrid $sendgrid)
    {
        $this->sendgrid = $sendgrid;
    }

    public function send(Message $message)
    {
        $sender = $message->getFrom()->current();

        $sgMessage = new Mail();
        $sgMessage->setFrom($sender->getEmail(), $sender->getName());
        $sgMessage->setSubject($message->getSubject());

        foreach ($message->getTo() as $address) {
            $sgMessage->addTo($address->getEmail(), $address->getName());
        }

        foreach ($message->getBcc() as $address) {
            $sgMessage->addBcc($address->getEmail(), $address->getName());
        }

        foreach ($message->getCc() as $address) {
            $sgMessage->addCc($address->getEmail(), $address->getName());
        }

        $sgMessage->addContent('text/html', $message->getBody());

        $this->sendgrid->send($sgMessage);
    }
}
