<?php
declare(strict_types=1);

namespace Tiara\Mail\Transport;

use Laminas\Mail;
use Laminas\Mail\Transport\TransportInterface;
use SendinBlue\Client\Api\TransactionalEmailsApi;
use SendinBlue\Client\ApiException;
use SendinBlue\Client\Model\SendSmtpEmail;
use SendinBlue\Client\Model\SendSmtpEmailBcc;
use SendinBlue\Client\Model\SendSmtpEmailCc;
use SendinBlue\Client\Model\SendSmtpEmailSender;
use SendinBlue\Client\Model\SendSmtpEmailTo;

/**
 * Class Transport
 *
 * @package Tiara\Mail\Sendinblue
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-mail
 */
final class SendinblueApi implements TransportInterface
{
    private TransactionalEmailsApi $api;

    /**
     * @param TransactionalEmailsApi $api
     */
    public function __construct(TransactionalEmailsApi $api)
    {
        $this->api = $api;
    }

    /**
     * @param Mail\Message $message
     * @throws ApiException
     */
    public function send(Mail\Message $message)
    {
        $sender = $message->getFrom()->current();

        $bcc = array_map(function (Mail\Address $address) {
            return new SendSmtpEmailBcc([
                'name' => $address->getName(),
                'email' => $address->getEmail(),
            ]);
        }, array_values(iterator_to_array($message->getBcc())));

        $cc = array_map(function (Mail\Address $address) {
            return new SendSmtpEmailCc([
                'name' => $address->getName(),
                'email' => $address->getEmail(),
            ]);
        }, array_values(iterator_to_array($message->getCc())));

        $sbMessage = new SendSmtpEmail([
            'sender' => new SendSmtpEmailSender([
                'name' => $sender->getName(),
                'email' => $sender->getEmail(),
            ]),
            'to' => array_map(function (Mail\Address $address) {
                return new SendSmtpEmailTo([
                    'name' => $address->getName(),
                    'email' => $address->getEmail(),
                ]);
            }, array_values(iterator_to_array($message->getTo()))),
            'bcc' => !empty($bcc) ? $bcc : null,
            'cc' => !empty($cc) ? $cc : null,
            'htmlContent' => $message->getBody(),
            'textContent' => null,
            'subject' => $message->getSubject(),
            'replyTo' => null,
            'attachment' => null,
            'headers' => null,
            'templateId' => null,
            'params' => null,
            'messageVersions' => null,
            'tags' => null,
        ]);

        $this->api->sendTransacEmail($sbMessage);
    }
}
