<?php
declare(strict_types=1);

namespace Tiara\Mail\Transport;

use GuzzleHttp\Client;
use Laminas\Mail\Transport\TransportInterface;
use Psr\Container\ContainerInterface;
use SendinBlue\Client\Api\TransactionalEmailsApi;
use SendinBlue\Client\Configuration;

/**
 * Class SendinblueApiFactory
 *
 * @package Tiara\Mail\Transport
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/tiara-mail
 */
final class SendinblueApiFactory
{
    public function __invoke(ContainerInterface $container): TransportInterface
    {
        $config = $container->get('config')['sendinblue'] ?? [];
        $config = Configuration::getDefaultConfiguration()->setApiKey('api-key', $config['api_key']);

        $apiInstance = new TransactionalEmailsApi(new Client(), $config);
        return new SendinblueApi($apiInstance);
    }
}